'use strict';

var ContJs = function (config)
{
    this.name = 'continuousUsage';
    this.single = function(name, value) {};
    this.all = function (storage) {};  

    this.elements = [];
    this.storage = {};

    if (typeof config !== 'undefined' && config !== null)
    {
        if (typeof config.name !== 'undefined' && config.name !== null) 
        {
            this.name = config.name;
        }

        if (typeof config.single !== 'undefined' && config.single !== null) 
        {
            this.single = config.single;
        }

        if (typeof config.all !== 'undefined' && config.all !== null) 
        {
            this.all = config.all;
        }
    }

    if (typeof window.localStorage === 'undefined') 
    {
        return;
    }

    this.init();
    this.bindFunctions();
};

ContJs.prototype.init = function ()
{
    var elements = document.getElementsByTagName('*');
    var self = this;

    Object.keys(elements).map(function (ind) 
    {
        if (elements[ind].attributes.getNamedItem('data-cont') !== null)
        {
            self.elements.push(elements[ind]);
        }
    });

    if (window.localStorage.getItem(this.name) === null)
    {
        this.reset();
    }

    this.load();
};

ContJs.prototype.bindFunctions = function ()
{
    var self = this;

    this.elements.map(function (element) 
    {
        var func = 'oninput';
        if (element.type === 'radio' || element.type === 'checkbox') 
        {
            func = 'onchange';
        }

        if (element.type !== 'password')
        {
            element[func] = function ()
            {
                var val = element.value;
                if (element.type === 'radio' || element.type === 'checkbox') 
                {
                    val = element.checked;
                    if (val) 
                    {
                    val = true;
                    }
                    else
                    {
                    val = false;
                    }
                }

                self.store(element.getAttribute('data-cont'), val);
            }
        }
    });
};

ContJs.prototype.store = function (name, value)
{
    this.single(name, value);  

    this.storage[name] = value;

    this.all(this.storage);

    window.localStorage.removeItem(this.name);
    window.localStorage.setItem(this.name, JSON.stringify(this.storage));
};

ContJs.prototype.load = function ()
{
    var self = this;  
    this.storage = JSON.parse(window.localStorage.getItem(this.name));  

    this.elements.map(function (element) 
    {    
        var val = self.storage[element.getAttribute('data-cont')];    

        if (typeof val !== 'undefined' && val !== null)
        {
            if (element.type === 'radio' || element.type === 'checkbox') 
            {
                element.checked = val;
            } 
            else
            {
                element.value = val;  
            }      
        }
    });
};

ContJs.prototype.reset = function ()
{
    window.localStorage.setItem(this.name, JSON.stringify({}));
    this.load();    
};

ContJs.prototype.remove = function (property)
{
    if (typeof this.storage[property] !== 'undefined' && this.storage[property] !== null)
    {
        delete this.storage[property];
    }

    window.localStorage.setItem(this.name, JSON.stringify(this.storage));
};

!function ()
{
  
    if (typeof exports !== 'undefined' && typeof module !== 'undefined' && typeof module.exports !== 'undefined')
    {
        module.exports = ContJs;  
    }

    if (typeof window !== 'undefined')
    {
        window.contJs = function (config)
        {
            return new ContJs(config);
        };
    }

}();